/* eslint-disable react/prop-types */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
import React, { useState, Children } from 'react';
import PropTypes from 'prop-types';
import InputContainer from './inputStyle';

export interface InputProps extends React.InputHTMLAttributes<HTMLElement> {
  value?: any;
  placeholder?: string;
  titleName?: string;
  onChange?: (e: any) => void;
  leftIconName?: string;
  leftIconColor?: string;
  leftIconSize?: number;
  rightIconName?: string;
  rightIconColor?: string;
  rightIconSize?: number;
  rightIconTitle?: string;
  rightIconOnClick?: () => void;
  defaultValue?: string;
  wrongText?: string;
  type?: any;
  maxLength?: number;
  width?: number;
  readOnly?: boolean;
  name?: any;
  inputBorderColor?: string;
  rightIconMouseDownCapture?: any;
  rightIconMouseUpCapture?: any;
  inputBackgroundColor?: string;
  children?: any;
  onBlur?: (e: any) => void;
  onFocus?: (e: any) => void;
}

const Input = React.forwardRef((props: InputProps, ref: any) => {
  const [blurState, setBlurState] = useState(0);
  const {
    value,
    placeholder,
    titleName,
    onChange,
    leftIconName,
    leftIconColor,
    leftIconSize,
    rightIconName,
    rightIconColor,
    rightIconSize,
    rightIconTitle,
    rightIconOnClick,
    defaultValue,
    wrongText,
    type,
    maxLength,
    width,
    readOnly,
    name,
    inputBorderColor,
    rightIconMouseDownCapture,
    rightIconMouseUpCapture,
    inputBackgroundColor,
    children,
    onBlur,
    onFocus,
    ...restProps
  } = props;

  const setBorder = () => {
    if (wrongText || (wrongText && inputBorderColor)) {
      return 'red';
    }
    if (inputBorderColor) {
      return inputBorderColor;
    }
    return '';
  };

  return (
    <InputContainer style={{ width: `${width}px` }}>
      <p className='title' style={{ display: titleName ? 'block' : 'none' }}>
        {titleName}
      </p>
      <div
        className={`inputBody fadeAnim ${blurState ? 'active ' : ''}${readOnly ? 'readOnlyOpacity ' : ''}`}
        style={{
          borderColor: setBorder(),
          background: inputBackgroundColor || '#fff',
        }}
      >
        <span className={`iconfont ${leftIconName || ''}`} style={{ color: `${leftIconColor}`, fontSize: `${leftIconSize}px ` }} />
        <input
          ref={ref}
          name={name}
          disabled={readOnly ? true : false}
          type={type}
          defaultValue={defaultValue}
          placeholder={placeholder}
          className='text '
          maxLength={maxLength}
          readOnly={readOnly}
          onChange={e => {
            const val = e.target.value;
            onChange && onChange(val);
          }}
          value={value}
          onBlur={e => {
            setBlurState(0);
            onBlur && onBlur(e.target.value);
          }}
          onFocus={e => {
            setBlurState(1);
            onFocus && onFocus(e.target.value);
          }}
          {...restProps}
        />
        <span
          title={rightIconTitle}
          onClick={() => rightIconOnClick && rightIconOnClick()}
          onMouseDownCapture={() => rightIconMouseDownCapture()}
          onMouseUpCapture={() => rightIconMouseUpCapture()}
          className={`iconfont ${rightIconName || ''}`}
          style={{ color: `${rightIconColor}`, fontSize: `${rightIconSize}px` }}
        />
        {Children.toArray(children)}
      </div>

      <p className='wrongText' style={{ display: wrongText ? 'block' : 'none' }}>
        {wrongText}
      </p>
    </InputContainer>
  );
});

Input.defaultProps = {
  type: 'text',
  placeholder: '请输入',
  onChange: () => {},
  rightIconOnClick: () => {},
  onFocus: () => {},
  onBlur: () => {},
};

Input.propTypes = {
  defaultValue: PropTypes.string,
  value: PropTypes.node,
  placeholder: PropTypes.string,
  onChange: PropTypes.func,
  leftIconName: PropTypes.string,
  leftIconColor: PropTypes.string,
  leftIconSize: PropTypes.number,
  rightIconName: PropTypes.string,
  rightIconColor: PropTypes.string,
  rightIconSize: PropTypes.number,
  rightIconTitle: PropTypes.string,
  rightIconOnClick: PropTypes.func,
  rightIconMouseDownCapture: PropTypes.func,
  rightIconMouseUpCapture: PropTypes.func,
  wrongText: PropTypes.string,
  type: PropTypes.string,
  maxLength: PropTypes.number,
  width: PropTypes.number,
  readOnly: PropTypes.bool,
  name: PropTypes.node,
  inputBorderColor: PropTypes.string,
  titleName: PropTypes.string,
  inputBackgroundColor: PropTypes.string,
  onFocus: PropTypes.func,
  onBlur: PropTypes.func,
};

export default Input;
